from_hosts_expression_to_xname_vec

Function from_hosts_expression_to_xname_vec 

pub async fn from_hosts_expression_to_xname_vec(
    user_input: &str,
    is_include_siblings: bool,
    node_metadata_available_vec: Vec<Component>,
) -> Result<Vec<String>, Error>
Translates and filters a ‘host expression’ into a list of xnames. a host expression is a comma separated list of NIDs or XNAMEs, a regex or a hostlist NOTE: user can provice a host expression and expand the list to all siblings